@@ -29,7 +29,7 @@
 #include <dirent.h>
 #include <string.h>
 
-#include <libgnome/libgnome.h>
+#include <glib/gi18n.h>
 #include <libgnomevfs/gnome-vfs-types.h>
 #include <libgnomevfs/gnome-vfs-uri.h>
 #include <libgnomevfs/gnome-vfs-utils.h>
@@ -38,9 +38,15 @@
 #include <libxml/xmlmemory.h>
 #include <gtk/gtk.h>
 
+#ifdef HAVE_LIBIPTCDATA
+#include <libiptcdata/iptc-data.h>
+#include <libiptcdata/iptc-jpeg.h>
+#endif /* HAVE_LIBIPTCDATA */
+
 #include "typedefs.h"
 #include "comments.h"
 #include "file-utils.h"
+#include "glib-utils.h"
 #include "gtk-utils.h"
 
 #define COMMENT_TAG  "Comment"
@@ -53,11 +59,11 @@
 
 
 CommentData *
-comment_data_new ()
+comment_data_new (void)
 {
 	CommentData *data;
 
-	data = g_new (CommentData, 1);
+	data = g_new0 (CommentData, 1);
 
 	data->place = NULL;
 	data->time = 0;
@@ -66,6 +72,12 @@ comment_data_new ()
 	data->keywords = NULL;
 	data->utf8_format = TRUE;
 
+#ifdef HAVE_LIBIPTCDATA
+	data->iptc_data = NULL;
+#endif /* HAVE_LIBIPTCDATA */
+
+	data->changed = FALSE;
+
 	return data;
 }
 
@@ -113,6 +125,11 @@ comment_data_free (CommentData *data)
 	comment_data_free_comment (data);
 	comment_data_free_keywords (data);
 
+#ifdef HAVE_LIBIPTCDATA
+	if (data->iptc_data != NULL)
+		iptc_data_unref (data->iptc_data);
+#endif /* HAVE_LIBIPTCDATA */
+
         g_free (data);
 }
 
@@ -142,10 +159,44 @@ comment_data_dup (CommentData *data)
 	}
 	new_data->utf8_format = data->utf8_format;
 
+#ifdef HAVE_LIBIPTCDATA
+	new_data->iptc_data = data->iptc_data;
+	if (new_data->iptc_data != NULL)
+		iptc_data_ref (new_data->iptc_data);
+#endif /* HAVE_LIBIPTCDATA */
+
 	return new_data;
 }
 
 
+gboolean
+comment_data_equal (CommentData *data1, 
+		    CommentData *data2)
+{
+	int i;
+
+	if ((data1 == NULL) && (data2 == NULL))
+		return TRUE;
+	if ((data1 == NULL) || (data2 == NULL))
+		return FALSE;
+
+	if (strcmp_null_tollerant (data1->place, data2->place) != 0)
+		return FALSE;
+	if (data1->time != data2->time)
+		return FALSE;
+	if (strcmp_null_tollerant (data1->comment, data2->comment) != 0)
+		return FALSE;
+	if (data1->keywords_n != data2->keywords_n)
+		return FALSE;
+	for (i = 0; i < data1->keywords_n; i++)
+		if (strcmp_null_tollerant (data1->keywords[i], 
+					   data2->keywords[i]) != 0)
+			return FALSE;
+
+	return TRUE;
+}
+
+
 char *
 comments_get_comment_filename__old (const char *source,
 				    gboolean    resolve_symlinks,
@@ -287,6 +338,293 @@ comments_get_comment_filename (const char *source,
 }
 
 
+#ifdef HAVE_LIBIPTCDATA
+
+
+static CommentData *
+load_comment_from_iptc (const char *filename)
+{
+	CommentData *data;
+	IptcData    *d;
+	struct tm    t;
+	int          i;
+	int          got_date = 0, got_time = 0;
+
+	d = iptc_data_new_from_jpeg (filename);
+	if (!d)
+		return NULL;
+
+	data = comment_data_new ();
+
+	bzero (&t, sizeof (t));
+	t.tm_isdst = -1;
+
+	for (i = 0; i < d->count; i++) {
+		IptcDataSet * ds = d->datasets[i];
+
+		if (ds->record == IPTC_RECORD_APP_2 &&
+				ds->tag == IPTC_TAG_CAPTION) {
+			if (data->comment)
+				continue;
+			data->comment = g_new (char, ds->size + 1);
+			if (data->comment)
+				iptc_dataset_get_data (ds, data->comment, ds->size + 1);
+		}
+		else if (ds->record == IPTC_RECORD_APP_2 &&
+				ds->tag == IPTC_TAG_CONTENT_LOC_NAME) {
+			if (data->place)
+				continue;
+			data->place = g_new (char, ds->size + 1);
+			if (data->place)
+				iptc_dataset_get_data (ds, data->place, ds->size + 1);
+		}
+		else if (ds->record == IPTC_RECORD_APP_2 &&
+				ds->tag == IPTC_TAG_KEYWORDS) {
+			char keyword[64];
+			if (iptc_dataset_get_data (ds, keyword, sizeof(keyword)) < 0)
+				continue;
+			comment_data_add_keyword (data, keyword);
+		}
+		else if (ds->record == IPTC_RECORD_APP_2 &&
+				ds->tag == IPTC_TAG_DATE_CREATED) {
+			int year, month;
+			iptc_dataset_get_date (ds, &year, &month, &t.tm_mday);
+			t.tm_year = year - 1900;
+			t.tm_mon = month - 1;
+			got_date = 1;
+		}
+		else if (ds->record == IPTC_RECORD_APP_2 &&
+				ds->tag == IPTC_TAG_TIME_CREATED) {
+			iptc_dataset_get_time (ds, &t.tm_hour, &t.tm_min, &t.tm_sec, NULL);
+			got_time = 1;
+		}
+	}
+
+	if (got_date && got_time)
+		data->time = mktime (&t);
+
+	data->iptc_data = d;
+
+	return data;
+}
+
+static void
+clear_iptc_comment (IptcData *d)
+{
+	int i;
+	IptcDataSet *ds;
+	IptcTag deletetag[] = {
+		IPTC_TAG_DATE_CREATED, IPTC_TAG_TIME_CREATED, IPTC_TAG_KEYWORDS,
+		IPTC_TAG_CAPTION, IPTC_TAG_CONTENT_LOC_NAME, 0
+	};
+
+	for (i = 0; deletetag[i] != 0; i++) {
+		while ((ds = iptc_data_get_dataset (d, IPTC_RECORD_APP_2,
+						deletetag[i]))) {
+			iptc_data_remove_dataset (d, ds);
+			iptc_dataset_unref (ds);
+		}
+	}
+}
+
+
+static void
+save_iptc_data (const char *filename, IptcData *d)
+{
+	int buf_len = 256 * 256;
+	FILE *infile, *outfile;
+	char *ps3_buf;
+	char *ps3_out_buf;
+	unsigned char *iptc_buf;
+	int ps3_len, iptc_len;
+	gchar *tmpfile;
+	struct stat statinfo;
+
+	ps3_buf = g_malloc (buf_len);
+	if (!ps3_buf)
+		return;
+
+	ps3_out_buf = g_malloc (buf_len);
+	if (!ps3_out_buf)
+		goto abort1;
+
+	infile = fopen (filename, "r");
+	if (!infile)
+		goto abort2;
+
+	ps3_len = iptc_jpeg_read_ps3 (infile, ps3_buf, buf_len);
+	if (ps3_len < 0)
+		goto abort3;
+
+	if (iptc_data_save (d, &iptc_buf, &iptc_len) < 0)
+		goto abort3;
+
+	ps3_len = iptc_jpeg_ps3_save_iptc (ps3_buf, ps3_len, iptc_buf,
+			iptc_len, ps3_out_buf, buf_len);
+	iptc_data_free_buf (d, iptc_buf);
+	if (ps3_len < 0)
+		goto abort3;
+
+	rewind (infile);
+
+	tmpfile = g_strdup_printf ("%s.%d", filename, getpid());
+	if (!tmpfile)
+		goto abort3;
+
+	outfile = fopen (tmpfile, "w");
+	if (!outfile)
+		goto abort4;
+	
+	if (iptc_jpeg_save_with_ps3 (infile, outfile, ps3_out_buf, ps3_len) < 0)
+		goto abort5;
+
+	fclose (outfile);
+	fclose (infile);
+
+	stat (filename, &statinfo);
+
+	if (rename (tmpfile, filename) < 0)
+		file_unlink (tmpfile);
+	else {
+		chown (filename, -1, statinfo.st_gid);
+		chmod (filename, statinfo.st_mode);
+	}
+
+	g_free (tmpfile);
+	g_free (ps3_out_buf);
+	g_free (ps3_buf);
+
+	return;
+abort5:
+	fclose (outfile);
+	file_unlink (tmpfile);
+abort4:
+	g_free (tmpfile);
+abort3:
+	fclose (infile);
+abort2:
+	g_free (ps3_out_buf);
+abort1:
+	g_free (ps3_buf);
+}
+
+
+static void
+save_comment_iptc (const char  *filename,
+		   CommentData *data)
+{
+	IptcData    *d;
+	IptcDataSet *ds;
+	time_t       mtime;
+	int          i;
+
+	mtime = get_file_mtime (filename);
+
+	d = iptc_data_new_from_jpeg (filename);
+	if (d) {
+		clear_iptc_comment (d);
+	}
+	else {
+		d = iptc_data_new ();
+		if (!d)
+			return;
+	}
+
+	if (data->time > 0) {
+		struct tm t;
+		localtime_r (&data->time, &t);
+		
+		ds = iptc_dataset_new ();
+		if (ds) {
+			iptc_dataset_set_tag (ds, IPTC_RECORD_APP_2,
+					IPTC_TAG_DATE_CREATED);
+			iptc_dataset_set_date (ds, t.tm_year + 1900, t.tm_mon + 1,
+					t.tm_mday, IPTC_DONT_VALIDATE);
+			iptc_data_add_dataset (d, ds);
+			iptc_dataset_unref (ds);
+		}
+
+		ds = iptc_dataset_new ();
+		if (ds) {
+			iptc_dataset_set_tag (ds, IPTC_RECORD_APP_2,
+					IPTC_TAG_TIME_CREATED);
+			iptc_dataset_set_time (ds, t.tm_hour, t.tm_min, t.tm_sec,
+					0, IPTC_DONT_VALIDATE);
+			iptc_data_add_dataset (d, ds);
+			iptc_dataset_unref (ds);
+		}
+	}
+
+	for (i = 0; i < data->keywords_n; i++) {
+		ds = iptc_dataset_new ();
+		if (ds) {
+			iptc_dataset_set_tag (ds, IPTC_RECORD_APP_2,
+					IPTC_TAG_KEYWORDS);
+			iptc_dataset_set_data (ds, data->keywords[i],
+					strlen (data->keywords[i]), IPTC_DONT_VALIDATE);
+			iptc_data_add_dataset (d, ds);
+			iptc_dataset_unref (ds);
+		}
+	}
+
+	if (data->comment != NULL && data->comment[0]) {
+		ds = iptc_dataset_new ();
+		if (ds) {
+			iptc_dataset_set_tag (ds, IPTC_RECORD_APP_2,
+					IPTC_TAG_CAPTION);
+			iptc_dataset_set_data (ds, data->comment,
+					strlen (data->comment), IPTC_DONT_VALIDATE);
+			iptc_data_add_dataset (d, ds);
+			iptc_dataset_unref (ds);
+		}
+	}
+
+	if (data->place != NULL && data->place[0]) {
+		ds = iptc_dataset_new ();
+		if (ds) {
+			iptc_dataset_set_tag (ds, IPTC_RECORD_APP_2,
+					IPTC_TAG_CONTENT_LOC_NAME);
+			iptc_dataset_set_data (ds, data->place,
+					strlen (data->place), IPTC_DONT_VALIDATE);
+			iptc_data_add_dataset (d, ds);
+			iptc_dataset_unref (ds);
+		}
+	}
+
+	iptc_data_set_version (d, IPTC_IIM_VERSION);
+	iptc_data_set_encoding_utf8 (d);
+	iptc_data_sort (d);
+
+	save_iptc_data (filename, d);
+	set_file_mtime (filename, mtime);
+
+	iptc_data_unref (d);
+}
+
+
+static void
+delete_comment_iptc (const char  *filename)
+{
+	IptcData *d;
+	time_t    mtime;
+
+	mtime = get_file_mtime (filename);
+
+	d = iptc_data_new_from_jpeg (filename);
+	if (!d)
+		return;
+
+	clear_iptc_comment (d);
+	save_iptc_data (filename, d);
+	set_file_mtime (filename, mtime);
+
+	iptc_data_unref (d);
+}
+
+
+#endif /* HAVE_LIBIPTCDATA */
+
+
 void
 comment_copy (const char *src,
 	      const char *dest)
@@ -302,7 +640,7 @@ comment_copy (const char *src,
 
 	comment_dest = comments_get_comment_filename (dest, TRUE, TRUE);
 	if (path_is_file (comment_dest)) 
-		unlink (comment_dest);
+		file_unlink (comment_dest);
 
 	file_copy (comment_src, comment_dest);
 
@@ -326,7 +664,7 @@ comment_move (const char *src,
 
 	comment_dest = comments_get_comment_filename (dest, TRUE, TRUE);
 	if (path_is_file (comment_dest)) 
-		unlink (comment_dest);
+		file_unlink (comment_dest);
 
 	file_move (comment_src, comment_dest);
 
@@ -341,8 +679,13 @@ comment_delete (const char *filename)
 	char *comment_name;
 
 	comment_name = comments_get_comment_filename (filename, TRUE, TRUE);
-	unlink (comment_name);
+	file_unlink (comment_name);
 	g_free (comment_name);
+
+#ifdef HAVE_LIBIPTCDATA
+	if (image_is_jpeg (filename)) 
+		delete_comment_iptc (filename);
+#endif /* HAVE_LIBIPTCDATA */
 }
 
 
@@ -382,7 +725,7 @@ check_comment_file (char     *real_file,
 	CommentsRemoveData *crd = data;
 
 	if (crd->clear_all || ! path_is_file (real_file)) {
-		if ((unlink (rc_file) < 0)) 
+		if (! file_unlink (rc_file)) 
 			g_warning ("Cannot delete %s\n", rc_file);
 	}
 }
@@ -403,7 +746,7 @@ remove_comments_done (const GList *dir_list,
 
 	for (scan = dir_list; scan; scan = scan->next) {
 		char *dir = scan->data;
-		rmdir (dir);
+		dir_remove (dir);
 	}
 }
 
@@ -523,8 +866,8 @@ get_keywords (CommentData *data,
 }
 
 
-CommentData *
-comments_load_comment (const char *filename)
+static CommentData *
+load_comment_from_xml (const char *filename)
 {
 	CommentData *data;
 	char        *comment_file;
@@ -548,12 +891,7 @@ comments_load_comment (const char *filename)
 		return NULL;
 	}
 
-	data = g_new (CommentData, 1);
-        data->place = NULL;
-        data->time = 0;
-        data->comment = NULL;
-        data->keywords = NULL;
-        data->keywords_n = 0;
+	data = comment_data_new ();
 
         root = xmlDocGetRootElement (doc);
         node = root->xmlChildrenNode;
@@ -586,13 +924,14 @@ comments_load_comment (const char *filename)
         xmlFreeDoc (doc);
 	g_free (comment_file);
 
-	return data;
+	return data;	
 }
 
 
 void
 save_comment (const char  *filename,
-	      CommentData *data)
+	      CommentData *data,
+	      gboolean     save_embedded)
 {
 	xmlDocPtr    doc;
         xmlNodePtr   tree, subtree;
@@ -607,6 +946,13 @@ save_comment (const char  *filename,
 		return;
 	}
 
+	if (save_embedded) {
+#ifdef HAVE_LIBIPTCDATA
+		if (image_is_jpeg (filename)) 
+			save_comment_iptc (filename, data);
+#endif /* HAVE_LIBIPTCDATA */
+	}
+
 	/* Convert data to strings. */
 
 	time_str = g_strdup_printf ("%ld", data->time);
@@ -665,20 +1011,59 @@ save_comment (const char  *filename,
 }
 
 
+CommentData *
+comments_load_comment (const char *filename,
+		       gboolean    try_embedded)
+{
+	CommentData *xml_comment = NULL, *img_comment = NULL;
+
+	if (filename == NULL)
+		return NULL;
+
+	xml_comment = load_comment_from_xml (filename);
+
+	if (try_embedded) {
+#ifdef HAVE_LIBIPTCDATA
+		if (image_is_jpeg (filename)) 
+			img_comment = load_comment_from_iptc (filename);
+		if (img_comment != NULL) {
+			if (xml_comment == NULL)
+				xml_comment = comment_data_new ();
+			xml_comment->iptc_data = img_comment->iptc_data;
+			if (xml_comment->iptc_data != NULL)
+				iptc_data_ref (xml_comment->iptc_data);
+		}
+#endif /* HAVE_LIBIPTCDATA */
+		if ((img_comment != NULL)
+		    && (! comment_data_equal (xml_comment, img_comment))) {
+			/* Consider the image comment more up-to-date and 
+			 * sync the xml comment with it. */
+			save_comment (filename, img_comment, FALSE);
+			comment_data_free (xml_comment);
+			xml_comment = img_comment;
+			xml_comment->changed = TRUE;
+		} else 
+			comment_data_free (img_comment);
+	}
+
+	return xml_comment;
+}
+
+
 void
 comments_save_comment (const char  *filename,
 		       CommentData *data)
 {
 	CommentData *new_data;
 
-	new_data = comments_load_comment (filename);
+	new_data = comments_load_comment (filename, TRUE);
 
 	if (new_data == NULL) {
 		CommentData *data_without_categories;
 
 		data_without_categories = comment_data_dup (data);
 		comment_data_free_keywords (data_without_categories);
-		save_comment (filename, data_without_categories);
+		save_comment (filename, data_without_categories, TRUE);
 		comment_data_free (data_without_categories);
 
 		return;
@@ -692,7 +1077,7 @@ comments_save_comment (const char  *filename,
 	if (data->comment != NULL) 
 		new_data->comment = g_strdup (data->comment);
 
-	save_comment (filename, new_data);
+	save_comment (filename, new_data, TRUE);
 	comment_data_free (new_data);
 }
 
@@ -703,7 +1088,7 @@ comments_save_comment_non_null (const char  *filename,
 {
 	CommentData *new_data;
 
-	new_data = comments_load_comment (filename);
+	new_data = comments_load_comment (filename, TRUE);
 	if (new_data == NULL) {
 		comments_save_comment (filename, data);
 		return;
@@ -737,14 +1122,14 @@ comments_save_categories (const char  *filename,
 {
 	CommentData *new_data;
 
-	new_data = comments_load_comment (filename);
+	new_data = comments_load_comment (filename, TRUE);
 
 	if (new_data == NULL) {
 		CommentData *data_without_comment;
 
 		data_without_comment = comment_data_dup (data);
 		comment_data_free_comment (data_without_comment);
-		save_comment (filename, data_without_comment);
+		save_comment (filename, data_without_comment, TRUE);
 		comment_data_free (data_without_comment);
 
 		return;
@@ -764,71 +1149,11 @@ comments_save_categories (const char  *filename,
 		new_data->keywords[i] = NULL;
 	}
 
-	save_comment (filename, new_data);
+	save_comment (filename, new_data, TRUE);
 	comment_data_free (new_data);
 }
 
 
-char *
-comments_get_comment_as_string (CommentData *data, 
-				char        *sep1, 
-				char        *sep2)
-{
-	char      *as_string = NULL;
-	char       time_txt[50] = "";
-	char      *utf8_time_txt = NULL;
-	struct tm *tm;
-
-	if (data == NULL)
-		return NULL;
- 
-	if (data->time != 0) {
-		tm = localtime (& data->time);
-		if (tm->tm_hour + tm->tm_min + tm->tm_sec == 0)
-			strftime (time_txt, 50, _("%d %B %Y"), tm);
-		else
-			strftime (time_txt, 50, _("%d %B %Y, %H:%M"), tm);
-		utf8_time_txt = g_locale_to_utf8 (time_txt, -1, 0, 0, 0);
-	} 
-
-	if ((data->comment == NULL) 
-	    && (data->place == NULL) 
-	    && (data->time == 0)) {
-		if (data->keywords_n > 0) 
-			as_string = NULL;
-		else
-			as_string = g_strdup (_("(No Comment)"));
-	} else {
-		GString *comment;
-
-		comment = g_string_new ("");
-
-		if (data->comment != NULL) 
-			g_string_append (comment, data->comment);
-
-		if ((data->comment != NULL)
-		    && ((data->place != NULL) || (*time_txt != 0)))
-			g_string_append (comment, sep1);
-		
-		if (data->place != NULL) 
-			g_string_append (comment, data->place);
-
-		if ((data->place != NULL) && (*time_txt != 0))
-			g_string_append (comment, sep2);
-
-		if (utf8_time_txt != NULL) 
-			g_string_append (comment, utf8_time_txt);
-
-		as_string = comment->str;
-		g_string_free (comment, FALSE);
-	}
-
-	g_free (utf8_time_txt);
-
-	return as_string;
-}
-
-
 void
 comment_data_remove_keyword (CommentData *data,
 			     const char  *keyword)
@@ -904,3 +1229,182 @@ comment_data_is_void (CommentData *data)
 
 	return TRUE;
 }
+
+
+gboolean
+comment_text_is_void (CommentData *data)
+{
+	if (data == NULL)
+		return TRUE;
+
+	if ((data->place != NULL) && (*data->place != 0))
+		return FALSE;
+	if (data->time > 0)
+		return FALSE;
+	if ((data->comment != NULL) && (*data->comment != 0))
+		return FALSE;
+
+	return TRUE;
+}
+
+
+/* From: glib/glib/gmarkup.c (Copyright 2000, 2003 Red Hat, Inc.)  
+ * This version does not escape ' and ''. Needed  because IE does not recognize
+ * &apos; and &quot; */
+static void
+_append_escaped_text_for_html (GString     *str,
+			       const gchar *text,
+			       gssize       length)
+{
+	const gchar *p;
+	const gchar *end;
+
+	p = text;
+	end = text + length;
+	
+	while (p != end) {
+		const gchar *next;
+		next = g_utf8_next_char (p);
+		
+		switch (*p) {
+		case '&':
+			g_string_append (str, "&amp;");
+			break;
+			
+		case '<':
+			g_string_append (str, "&lt;");
+			break;
+			
+		case '>':
+			g_string_append (str, "&gt;");
+			break;
+			
+		case '\n':
+			g_string_append (str, "<br />");
+			break;
+
+		default:
+			g_string_append_len (str, p, next - p);
+			break;
+		}
+		
+		p = next;
+	}
+}
+
+
+char*
+_g_escape_text_for_html (const gchar *text,
+			 gssize       length)
+{
+	GString *str;
+
+	g_return_val_if_fail (text != NULL, NULL);
+	
+	if (length < 0)
+		length = strlen (text);
+
+	/* prealloc at least as long as original text */
+	str = g_string_sized_new (length);
+	_append_escaped_text_for_html (str, text, length);
+
+	return g_string_free (str, FALSE);
+}
+
+
+static void
+_string_append (GString    *str,
+		const char *a,
+		gboolean    markup_escape) 
+{
+	if (a == NULL)
+		return;
+
+ 	if (markup_escape)
+		_append_escaped_text_for_html (str, a, strlen (a));
+	else 
+		g_string_append (str, a);
+}
+
+
+/* Note: separators are not escaped */
+static char *
+_get_comment_as_string_common (CommentData *data, 
+			       char        *sep1, 
+			       char        *sep2,
+			       gboolean     markup_escape)
+{
+	char      *as_string = NULL;
+	char       time_txt[50] = "";
+	char      *utf8_time_txt = NULL;
+	struct tm *tm;
+
+	if (data == NULL)
+		return NULL;
+ 
+	if (data->time != 0) {
+		tm = localtime (& data->time);
+		if (tm->tm_hour + tm->tm_min + tm->tm_sec == 0)
+			strftime (time_txt, 50, _("%d %B %Y"), tm);
+		else
+			strftime (time_txt, 50, _("%d %B %Y, %H:%M"), tm);
+		utf8_time_txt = g_locale_to_utf8 (time_txt, -1, 0, 0, 0);
+	} 
+
+	if ((data->comment == NULL) 
+	    && (data->place == NULL) 
+	    && (data->time == 0)) {
+		if (data->keywords_n > 0) 
+			as_string = NULL;
+		else if (markup_escape)
+			as_string = g_markup_escape_text (_("(No Comment)"), -1);
+		else
+			as_string = g_strdup (_("(No Comment)"));
+		
+	} else {
+		GString *comment;
+
+		comment = g_string_new ("");
+
+		if (data->comment != NULL) 
+			_string_append (comment, data->comment, markup_escape);
+
+		if ((data->comment != NULL)
+		    && ((data->place != NULL) || (*time_txt != 0)))
+			g_string_append (comment, sep1);
+		
+		if (data->place != NULL) 
+			_string_append (comment, data->place, markup_escape);
+
+		if ((data->place != NULL) && (*time_txt != 0))
+			g_string_append (comment, sep2);
+		
+		if (utf8_time_txt != NULL) 
+			_string_append (comment, utf8_time_txt, markup_escape);
+		
+		as_string = comment->str;
+		g_string_free (comment, FALSE);
+	}
+	
+	g_free (utf8_time_txt);
+	
+	return as_string;
+}
+
+
+char *
+comments_get_comment_as_string (CommentData *data, 
+				char        *sep1, 
+				char        *sep2)
+{
+	return _get_comment_as_string_common (data, sep1, sep2, FALSE);
+}
+
+
+char *
+comments_get_comment_as_xml_string (CommentData *data, 
+				    char        *sep1, 
+				    char        *sep2)
+{
+	return _get_comment_as_string_common (data, sep1, sep2, TRUE);
+}
