@@ -21,9 +21,10 @@
  */
 
 #include <config.h>
-#include <gtk/gtk.h>
 #include <string.h>
-#include <libgnome/libgnome.h>
+
+#include <glib/gi18n.h>
+#include <gtk/gtk.h>
 #include <libgnomevfs/gnome-vfs-types.h>
 #include <libgnomevfs/gnome-vfs-ops.h>
 #include <libgnomevfs/gnome-vfs-file-info.h>
@@ -313,6 +314,9 @@ gth_file_list_init (GthFileList *file_list)
 	gtk_container_add (GTK_CONTAINER (scrolled_window), gth_file_view_get_widget (file_list->view));
 
 	file_list->root_widget = scrolled_window;
+	file_list->drag_source = gth_file_view_get_drag_source (file_list->view);
+	if (file_list->drag_source == NULL)
+		file_list->drag_source = file_list->root_widget;
 
 	/* signals */
 
@@ -506,10 +510,12 @@ set_list__step2 (GetFileInfoData *gfi_data)
 
 
 void 
-gth_file_list_set_list (GthFileList *file_list,
-			GList       *new_list,
-			DoneFunc     done_func,
-			gpointer     done_func_data)
+gth_file_list_set_list (GthFileList   *file_list,
+			GList         *new_list,
+			GthSortMethod  sort_method,
+			GtkSortType    sort_type,
+			DoneFunc       done_func,
+			gpointer       done_func_data)
 {
 	GetFileInfoData *gfi_data;
 	GList           *scan;
@@ -522,6 +528,8 @@ gth_file_list_set_list (GthFileList *file_list,
 	gth_file_view_set_no_image_text (file_list->view, _("Wait please..."));
 	gth_file_view_clear (file_list->view); 
 
+	file_list->sort_method = sort_method;
+	file_list->sort_type = sort_type;
 	file_list->interrupt_set_list = FALSE;
 	gfi_data = get_file_info_data_new (file_list, 
 					   done_func, 
@@ -532,7 +540,6 @@ gth_file_list_set_list (GthFileList *file_list,
 	for (scan = new_list; scan; scan = scan->next) {
 		char        *full_path = scan->data;
 		const char  *name_only = file_name_from_path (full_path);
-		char        *escaped;
 		GnomeVFSURI *uri;
 
 		if ((! gfi_data->file_list->show_dot_files 
@@ -540,10 +547,7 @@ gth_file_list_set_list (GthFileList *file_list,
 		    || ! file_is_image (full_path, fast_file_type))
 			continue;
 
-		escaped = escape_uri (full_path);
-		uri = gnome_vfs_uri_new (escaped);
-		g_free (escaped);
-
+		uri = new_uri_from_path (full_path);
 		if (uri != NULL)
 			gfi_data->uri_list = g_list_prepend (gfi_data->uri_list, uri);
 	}
@@ -653,7 +657,7 @@ add_list_in_chunks (gpointer callback_data)
 		FileData *fd = scan->data;
 		int       pos;
 
-		file_data_update_comment (fd);
+		file_data_update_comment (fd); 
 		
 		pos = gth_file_view_append_with_data (file_list->view,
 						      NULL,
@@ -776,7 +780,6 @@ gth_file_list_add_list (GthFileList *file_list,
 	for (scan = new_list; scan; scan = scan->next) {
 		char        *full_path = scan->data;
 		const char  *name_only = file_name_from_path (full_path);
-		char        *escaped;
 		GnomeVFSURI *uri;
 
 		if (gth_file_list_pos_from_path (file_list, full_path) != -1)
@@ -787,10 +790,7 @@ gth_file_list_add_list (GthFileList *file_list,
 		    || ! file_is_image (full_path, eel_gconf_get_boolean (PREF_FAST_FILE_TYPE, TRUE)))
 			continue;
 		
-		escaped = escape_uri (full_path);
-		uri = gnome_vfs_uri_new (escaped);
-		g_free (escaped);
-
+		uri = new_uri_from_path (full_path);
 		if (uri != NULL)
 			gfi_data->uri_list = g_list_prepend (gfi_data->uri_list, uri);
 	}
@@ -876,7 +876,8 @@ set_sort_method__step2 (InterruptThumbsData *it_data)
 
 void 
 gth_file_list_set_sort_method (GthFileList   *file_list,
-			       GthSortMethod  new_method)
+			       GthSortMethod  new_method,
+			       gboolean       update)
 {
 	InterruptThumbsData *it_data;
 
@@ -885,6 +886,11 @@ gth_file_list_set_sort_method (GthFileList   *file_list,
 	if (file_list->sort_method == new_method) 
 		return;
 
+	if (! update) {
+		file_list->sort_method = new_method;
+		return;
+	}
+
 	if (file_list->doing_thumbs) {
 		it_data = it_data_new (file_list, TRUE, new_method, NULL);
 		gth_file_list_interrupt_thumbs (file_list, 
@@ -920,12 +926,18 @@ set_sort_type__step2 (InterruptThumbsData *it_data)
 
 void
 gth_file_list_set_sort_type (GthFileList *file_list,
-			     GtkSortType  sort_type)
+			     GtkSortType  sort_type,
+			     gboolean     update)
 {
 	InterruptThumbsData *it_data;
 
 	g_return_if_fail (file_list != NULL);
 
+	if (! update) {
+		file_list->sort_type = sort_type;
+		return;
+	}
+
 	if (file_list->doing_thumbs) {
 		it_data = it_data_new (file_list, TRUE, sort_type, NULL);
 		gth_file_list_interrupt_thumbs (file_list, 
@@ -1023,6 +1035,24 @@ gth_file_list_get_all (GthFileList *file_list)
 }
 
 
+GList *
+gth_file_list_get_all_from_view (GthFileList *file_list)
+{
+	GList *list;
+	GList *scan;
+
+	g_return_val_if_fail (file_list != NULL, NULL);
+
+	list = NULL;
+	for (scan = gth_file_view_get_list (file_list->view); scan; scan = scan->next) {
+		FileData *fd = scan->data;
+		list = g_list_prepend (list, g_strdup (fd->path));
+	}
+
+	return g_list_reverse (list);
+}
+
+
 int 
 gth_file_list_get_length (GthFileList *file_list)
 {
@@ -1145,7 +1175,8 @@ static void gth_file_list_update_thumbs (GthFileList *file_list);
 
 void
 gth_file_list_enable_thumbs (GthFileList *file_list,
-			     gboolean     enable)
+			     gboolean     enable,
+			     gboolean     update)
 {
 	int i;
 
@@ -1153,6 +1184,9 @@ gth_file_list_enable_thumbs (GthFileList *file_list,
 
 	file_list->enable_thumbs = enable;
 
+	if (!update)
+		return;
+
 	gth_file_view_enable_thumbs (file_list->view, file_list->enable_thumbs);
 
 	for (i = 0; i < gth_file_view_get_images (file_list->view); i++)
