@@ -35,6 +35,8 @@ static struct {
 	{ "search",        "dlg_catalog_edit_search" },
 	{ "search",        "dlg_catalog_search" },
 	{ "jpegtran",      "dlg_jpegtran" },
+	{ "jpegtran",      "dlg_apply_jpegtran" },
+	{ "jpegtran",      "dlg_apply_jpegtran_from_exif" },
 	{ "duplicates",    "dlg_duplicates" },
 	{ "photoimporter", "dlg_photo_importer" },
 	{ NULL, NULL }
