@@ -338,13 +338,8 @@ image_loader_set_path (ImageLoader *il,
 		gnome_vfs_uri_unref (priv->uri);
 		priv->uri = NULL;
 	}
-
-	if (path != NULL) {
-		char *escaped_path;
-		escaped_path = gnome_vfs_escape_path_string (path);
-		priv->uri = gnome_vfs_uri_new (escaped_path);
-		g_free (escaped_path);
-	}
+	if (path != NULL) 
+		priv->uri = new_uri_from_path (path);
 
 	g_mutex_unlock (priv->yes_or_no);
 }
@@ -434,7 +429,6 @@ image_loader_sync_pixbuf (ImageLoader *il)
 		g_object_unref (priv->pixbuf);
 		priv->pixbuf = NULL;
 	}
-
 	if (pixbuf != NULL) {
 		g_object_ref (pixbuf);
 		priv->pixbuf = pixbuf;
@@ -486,13 +480,11 @@ image_loader_sync_pixbuf_from_loader (ImageLoader     *il,
 		g_object_unref (priv->pixbuf);
 		priv->pixbuf = NULL;
 	}
-
 	if (pixbuf != NULL) {
 		g_object_ref (pixbuf);
 		priv->pixbuf = pixbuf;
 		/*priv->pixbuf = gdk_pixbuf_copy (pixbuf);*/
 	}
-
 	g_object_unref (pixbuf);
 
 	g_mutex_unlock (priv->yes_or_no);
@@ -634,7 +626,7 @@ image_loader_stop__final_step (ImageLoader *il)
 	priv->loading = FALSE;
 	
 	priv->done_func = NULL;
-	if (done_func != NULL)
+	if (done_func != NULL) 
 		(*done_func) (priv->done_func_data);
 	
 	if (! priv->emit_signal || priv->interrupted) {
@@ -763,6 +755,7 @@ image_loader_start__step2 (ImageLoader *il)
 				       GNOME_VFS_PRIORITY_DEFAULT,
 				       get_file_info_cb,
 				       il);
+
 	{
 		GList *scan;
 		for (scan = uri_list; scan; scan = scan->next) 
