@@ -67,21 +67,24 @@
 #define  PREF_CHECK_TYPE             "/apps/gthumb/viewer/check_type"
 #define  PREF_CHECK_SIZE             "/apps/gthumb/viewer/check_size"
 #define  PREF_BLACK_BACKGROUND       "/apps/gthumb/viewer/black_background"
+#define  PREF_SINGLE_WINDOW          "/apps/gthumb/viewer/single_window"
 
 #define  PREF_SLIDESHOW_DIR          "/apps/gthumb/slideshow/direction"
 #define  PREF_SLIDESHOW_DELAY        "/apps/gthumb/slideshow/delay"
 #define  PREF_SLIDESHOW_WRAP_AROUND  "/apps/gthumb/slideshow/wrap_around"
-#define  PREF_SLIDESHOW_FULLSCREEN   "/apps/gthumb/slideshow/fullscreen"
 
 #define  PREF_UI_LAYOUT              "/apps/gthumb/ui/layout"
 #define  PREF_UI_TOOLBAR_STYLE       "/apps/gthumb/ui/toolbar_style"
 #define  PREF_UI_WINDOW_WIDTH        "/apps/gthumb/ui/window_width"
 #define  PREF_UI_WINDOW_HEIGHT       "/apps/gthumb/ui/window_height"
+#define  PREF_UI_VIEWER_WIDTH        "/apps/gthumb/ui/viewer_width"
+#define  PREF_UI_VIEWER_HEIGHT       "/apps/gthumb/ui/viewer_height"
 #define  PREF_UI_IMAGE_PANE_VISIBLE  "/apps/gthumb/ui/image_pane_visible"
 #define  PREF_UI_TOOLBAR_VISIBLE     "/apps/gthumb/ui/toolbar_visible"
 #define  PREF_UI_STATUSBAR_VISIBLE   "/apps/gthumb/ui/statusbar_visible"
 #define  PREF_UI_SIDEBAR_SIZE        "/apps/gthumb/ui/sidebar_size"
 #define  PREF_UI_SIDEBAR_CONTENT_SIZE "/apps/gthumb/ui/sidebar_content_size"
+#define  PREF_UI_COMMENT_PANE_SIZE   "/apps/gthumb/ui/comment_pane_size"
 
 #define  PREF_EXP_NAME_TEMPLATE      "/apps/gthumb/exporter/general/name_template"
 #define  PREF_EXP_START_FROM         "/apps/gthumb/exporter/general/start_from"
@@ -173,12 +176,18 @@
 #define  PREF_PRINT_COMMENT_FONT      "/apps/gthumb/dialogs/print/comment_font"
 #define  PREF_PRINT_PAPER_WIDTH       "/apps/gthumb/dialogs/print/paper_width"
 #define  PREF_PRINT_PAPER_HEIGHT      "/apps/gthumb/dialogs/print/paper_height"
+#define  PREF_PRINT_MARGIN_LEFT       "/apps/gthumb/dialogs/print/margin_left"
+#define  PREF_PRINT_MARGIN_RIGHT      "/apps/gthumb/dialogs/print/margin_right"
+#define  PREF_PRINT_MARGIN_TOP        "/apps/gthumb/dialogs/print/margin_top"
+#define  PREF_PRINT_MARGIN_BOTTOM     "/apps/gthumb/dialogs/print/margin_bottom"
 #define  PREF_PRINT_PAPER_UNIT        "/apps/gthumb/dialogs/print/paper_unit"
 #define  PREF_PRINT_IMAGES_PER_PAGE   "/apps/gthumb/dialogs/print/images_per_page"
 
 #define  PREF_MSG_CANNOT_MOVE_TO_TRASH "/apps/gthumb/dialogs/messages/cannot_move_to_trash"
 #define  PREF_MSG_SAVE_MODIFIED_IMAGE  "/apps/gthumb/dialogs/messages/save_modified_image"
 
+#define  PREF_CHOOSE_DESTINATION_VIEW  "/apps/gthumb/dialogs/choose_destination/view"
+
 #define  PREF_PHOTO_IMPORT_DESTINATION    "/apps/gthumb/dialogs/photo_importer/destination"
 #define  PREF_PHOTO_IMPORT_FILM           "/apps/gthumb/dialogs/photo_importer/film"
 #define  PREF_PHOTO_IMPORT_DELETE         "/apps/gthumb/dialogs/photo_importer/delete_from_camera"
@@ -190,7 +199,7 @@
 #define  PREF_CROP_ASPECT_RATIO_WIDTH     "/apps/gthumb/dialogs/crop/aspect_ratio_width"
 #define  PREF_CROP_ASPECT_RATIO_HEIGHT    "/apps/gthumb/dialogs/crop/aspect_ratio_height"
 #define  PREF_ADD_TO_CATALOG_LAST_CATALOG "/apps/gthumb/dialogs/add_to_catalog/last_catalog"
-
+#define  PREF_ADD_TO_CATALOG_VIEW         "/apps/gthumb/dialogs/add_to_catalog/view"
 
 typedef struct {
 	Bookmarks   *bookmarks;
@@ -238,12 +247,17 @@ void            pref_util_get_rgb_values              (const char *hex,
 						       guint16    *g,
 						       guint16    *b);
 
+void            pref_util_get_color_from_hex          (const char *hex,
+						       GdkColor   *color);
+
 const char     *pref_util_get_hex_value               (guint16     r,
 						       guint16     g,
 						       guint16     b);
 
 guint32         pref_util_get_int_value               (const char *hex);
 
+guint32         pref_util_get_ui32_from_color         (GdkColor   *color);
+
 GthClickPolicy  pref_get_real_click_policy            (void);
 
 GthToolbarStyle pref_get_real_toolbar_style           (void);
