@@ -125,7 +125,8 @@ typedef enum { /*< skip >*/
 	GTH_SORT_METHOD_BY_NAME,
 	GTH_SORT_METHOD_BY_PATH,
 	GTH_SORT_METHOD_BY_SIZE,
-	GTH_SORT_METHOD_BY_TIME
+	GTH_SORT_METHOD_BY_TIME,
+	GTH_SORT_METHOD_MANUAL
 } GthSortMethod;
 
 
@@ -192,6 +193,33 @@ typedef enum { /*< skip >*/
 } GthCropRatio;
 
 
+typedef enum { /*< skip >*/
+	GTH_MONITOR_EVENT_CREATED,
+	GTH_MONITOR_EVENT_DELETED,
+	GTH_MONITOR_EVENT_CHANGED,
+	GTH_MONITOR_EVENT_RENAMED,
+} GthMonitorEvent;
+
+
+typedef enum { /*< skip >*/
+	GTH_TRANSFORM_ROTATE_0,
+	GTH_TRANSFORM_ROTATE_90,
+	GTH_TRANSFORM_ROTATE_180,
+	GTH_TRANSFORM_ROTATE_270,
+	GTH_TRANSFORM_NONE,
+	GTH_TRANSFORM_MIRROR,
+	GTH_TRANSFORM_FLIP
+} GthTransform;
+
+
+typedef enum { /*< skip >*/
+	GTH_DROP_POSITION_NONE,
+	GTH_DROP_POSITION_INTO,
+	GTH_DROP_POSITION_LEFT,
+	GTH_DROP_POSITION_RIGHT
+} GthDropPosition;
+
+
 typedef void (*ErrorFunc)      (gpointer data);
 
 typedef void (*DoneFunc)       (gpointer data);
