@@ -23,9 +23,18 @@
 #ifndef DLG_CATEGORIES_H
 #define DLG_CATEGORIES_H
 
-#include "gthumb-window.h"
+#include "typedefs.h"
+#include "gth-window.h"
 
-void   dlg_categories                   (GtkWidget    *widget,
-					 GThumbWindow *window);
+void        dlg_choose_categories    (GtkWindow     *parent,
+				      GList         *file_list,
+				      GList         *default_categories_list,
+				      GList        **add_categories_list,
+				      GList        **remove_categories_list,
+				      DoneFunc       done_func,
+				      gpointer       done_data);
+GtkWidget*  dlg_categories_new       (GthWindow     *window);
+void        dlg_categories_update    (GtkWidget     *dlg);
+void        dlg_categories_close     (GtkWidget     *dlg);
 
 #endif /* DLG_CATEGORIES_H */
