@@ -28,17 +28,20 @@
 #include <sys/types.h>
 #include <sys/wait.h>
 #include <string.h>
+
+#include <glib/gi18n.h>
 #include <gtk/gtk.h>
 #include <glade/glade.h>
 #include <libgnomeui/libgnomeui.h>
 #include <libgnomevfs/gnome-vfs.h>
+
 #include "catalog.h"
 #include "dlg-file-utils.h"
 #include "glib-utils.h"
 #include "gtk-utils.h"
 #include "gconf-utils.h"
 #include "gthumb-init.h"
-#include "gthumb-window.h"
+#include "gth-browser.h"
 #include "file-utils.h"
 #include "md5.h"
 #include "thumb-loader.h"
@@ -77,14 +80,13 @@ enum {
 
 
 typedef struct {
-	GThumbWindow        *window;
+	GthBrowser          *browser;
 	GladeXML            *gui;
 
 	GtkWidget           *dialog;
 	GtkWidget           *results_dialog;
 
-	GtkWidget           *fd_start_from_entry;
-	GtkWidget           *fd_start_from_fileentry;
+	GtkWidget           *fd_start_from_filechooserbutton;
 	GtkWidget           *fd_include_subfolders_checkbutton;
 
 	GtkWidget           *fdr_progress_table;
@@ -239,11 +241,11 @@ static void
 find_cb (GtkWidget  *widget,
 	 DialogData *data)
 {
-	char *utf8_path;
+	char *esc_path;
 
-	utf8_path = gnome_file_entry_get_full_path (GNOME_FILE_ENTRY (data->fd_start_from_fileentry), FALSE);
-	data->start_from_path = g_filename_from_utf8 (utf8_path, -1, 0, 0, 0);
-	g_free (utf8_path);
+	esc_path = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (data->fd_start_from_filechooserbutton));
+	data->start_from_path = gnome_vfs_unescape_string (esc_path, "");
+	g_free (esc_path);
 
 	data->recursive = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (data->fd_include_subfolders_checkbutton));
 
@@ -390,6 +392,7 @@ duplicates_add_columns (DialogData  *data,
                                              NULL);
 
 	gtk_tree_view_column_set_sizing (column, GTK_TREE_VIEW_COLUMN_AUTOSIZE);
+	gtk_tree_view_column_set_resizable (column, TRUE);
 	gtk_tree_view_column_set_sort_column_id (column, DCOLUMN_NAME);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (treeview), column);
 
@@ -540,11 +543,11 @@ images_selection_changed_cb (GtkTreeSelection *selection,
 			continue;
 
 		location = remove_level_from_path (idata2->path);
-		location_utf8 = g_filename_to_utf8 (location, -1, 0, 0, 0);
+		location_utf8 = g_filename_display_name (location);
 		g_free (location);
 			
 		name = file_name_from_path (idata2->path);
-		name_utf8 = g_filename_to_utf8 (name, -1, 0, 0, 0);
+		name_utf8 = g_filename_display_name (name);
 
 		tm = localtime (&idata2->last_modified);
 		strftime (time_txt, 50, _("%d %B %Y, %H:%M"), tm);
@@ -660,10 +663,10 @@ view_cb (GtkWidget  *widget,
 		catalog_add_item (catalog, (char*) scan->data);
 
 	if (! catalog_write_to_disk (catalog, &gerror)) 
-		_gtk_error_dialog_from_gerror_run (GTK_WINDOW (data->window->app), &gerror);
+		_gtk_error_dialog_from_gerror_run (GTK_WINDOW (data->browser), &gerror);
 	else {
 		/* View the Drag&Drop catalog. */
-		window_go_to_catalog (data->window, catalog_path);
+		gth_browser_go_to_catalog (data->browser, catalog_path);
 	}
 
 	catalog_free (catalog);
@@ -751,7 +754,7 @@ delete_cb (GtkWidget  *widget,
 	if (list == NULL)
 		return;
 
-	if (dlg_file_delete__confirm (data->window, 
+	if (dlg_file_delete__confirm (GTH_WINDOW (data->browser), 
 				      path_list_dup (list),
 				      _("Checked images will be moved to the Trash, are you sure?"))) 
 		delete_images_from_lists (data, list);
@@ -761,17 +764,17 @@ delete_cb (GtkWidget  *widget,
 
 
 void
-dlg_duplicates (GThumbWindow *window)
+dlg_duplicates (GthBrowser *browser)
 {
 	DialogData        *data;
 	GtkWidget         *ok_button;
 	GtkWidget         *close_button;
 	GtkTreeSelection  *selection;
-	GValue             value = {0, };
+	char              *esc_uri = NULL;
 
 	data = g_new0 (DialogData, 1);
 
-	data->window = window;
+	data->browser = browser;
 	data->gui = glade_xml_new (GTHUMB_GLADEDIR "/" GLADE_FILE, NULL,
 				   NULL);
 
@@ -785,8 +788,7 @@ dlg_duplicates (GThumbWindow *window)
 	data->dialog = glade_xml_get_widget (data->gui, "duplicates_dialog");
 	data->results_dialog = glade_xml_get_widget (data->gui, "duplicates_results_dialog");
 
-	data->fd_start_from_entry = glade_xml_get_widget (data->gui, "fd_start_from_entry");
-	data->fd_start_from_fileentry = glade_xml_get_widget (data->gui, "fd_start_from_fileentry");
+	data->fd_start_from_filechooserbutton = glade_xml_get_widget (data->gui, "fd_start_from_filechooserbutton");
 	data->fd_include_subfolders_checkbutton = glade_xml_get_widget (data->gui, "fd_include_subfolders_checkbutton");
 
 	data->fdr_progress_table = glade_xml_get_widget (data->gui, "fdr_progress_table");
@@ -810,14 +812,9 @@ dlg_duplicates (GThumbWindow *window)
 
 	/* Set widgets data. */
 
-	g_value_init (&value, G_TYPE_BOOLEAN);
-	g_value_set_boolean (&value, TRUE);
-	g_object_set_property (G_OBJECT (data->fd_start_from_fileentry), "use_filechooser", &value);
-
-	if (window->dir_list->path != NULL)
-		_gtk_entry_set_filename_text (GTK_ENTRY (data->fd_start_from_entry), window->dir_list->path);
-	else
-		_gtk_entry_set_filename_text (GTK_ENTRY (data->fd_start_from_entry), g_get_home_dir ());
+	esc_uri = gnome_vfs_escape_host_and_path_string (gth_browser_get_current_directory (data->browser));
+	gtk_file_chooser_set_uri (GTK_FILE_CHOOSER (data->fd_start_from_filechooserbutton), esc_uri);
+	g_free (esc_uri);
 
 	/* * Images model */
 
@@ -916,7 +913,7 @@ dlg_duplicates (GThumbWindow *window)
 	/* Run dialog. */
 
 	gtk_window_set_transient_for (GTK_WINDOW (data->dialog), 
-				      GTK_WINDOW (window->app));
+				      GTK_WINDOW (browser));
 	gtk_widget_grab_focus (data->fdr_stop_button);
 	gtk_widget_show (data->dialog);
 }
@@ -1560,17 +1557,12 @@ directory_load_cb (GnomeVFSAsyncHandle *handle,
 static void 
 search_dir_async (DialogData *data, const char *path)
 {
-	char *escaped;
-
 	_gtk_entry_set_filename_text (GTK_ENTRY (data->fdr_current_dir_entry), path);
 	gtk_entry_set_text (GTK_ENTRY (data->fdr_current_image_entry), "");
 
 	if (data->uri != NULL)
 		gnome_vfs_uri_unref (data->uri);
-
-	escaped = escape_uri (path);
-	data->uri = gnome_vfs_uri_new (escaped);
-	g_free (escaped);
+	data->uri = new_uri_from_path (path);
 
 	data->scanning_dir = TRUE;
 
@@ -1578,7 +1570,7 @@ search_dir_async (DialogData *data, const char *path)
 		& (data->handle),
 		data->uri,
 		GNOME_VFS_FILE_INFO_FOLLOW_LINKS,
-		32 /* items_per_notification FIXME */,
+		128 /* items_per_notification FIXME */,
 		GNOME_VFS_PRIORITY_MIN,
 		directory_load_cb,
 		data);
