@@ -3,7 +3,7 @@
 /*
  *  GThumb
  *
- *  Copyright (C) 2001, 2003 Free Software Foundation, Inc.
+ *  Copyright (C) 2001-2005 Free Software Foundation, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -27,13 +27,12 @@
 #include <fcntl.h>
 #include <unistd.h>
 
+#include <glib/gi18n.h>
 #include <gtk/gtk.h>
-#include <libgnome/libgnome.h>
-#include <libgnomeui/gnome-dialog.h>
-#include <libgnomeui/gnome-dialog-util.h>
-#include <libgnomeui/gnome-propertybox.h>
-#include <libgnomeui/gnome-pixmap.h>
+#include <libgnome/gnome-help.h>
+#include <libgnomevfs/gnome-vfs-utils.h>
 #include <glade/glade.h>
+
 #include "thumb-cache.h"
 #include "comments.h"
 #include "file-utils.h"
@@ -42,7 +41,7 @@
 #include "gconf-utils.h"
 #include "gtk-utils.h"
 #include "typedefs.h"
-#include "gthumb-window.h"
+#include "gth-browser.h"
 
 #include "icons/layout1.xpm"
 #include "icons/layout2.xpm"
@@ -55,46 +54,43 @@ static gint thumb_sizes = sizeof (thumb_size) / sizeof (gint);
 #define GLADE_PREF_FILE "gthumb_preferences.glade"
 
 typedef struct {
-	GThumbWindow    *window;
+	GthBrowser *browser;
 
-	GladeXML  *gui;
-	GtkWidget *dialog;
+	GladeXML   *gui;
+	GtkWidget  *dialog;
 
-	GtkWidget *radio_current_location;
-	GtkWidget *radio_last_location;
-	GtkWidget *radio_use_startup;
-	GtkWidget *startup_dir_entry;
-	GtkWidget *file_entry;
-	GtkWidget *btn_set_to_current;
-	GtkWidget *radio_layout1;
-	GtkWidget *radio_layout2;
-	GtkWidget *radio_layout3;
-	GtkWidget *radio_layout4;
-	GtkWidget *toolbar_style_optionmenu;
+	GtkWidget  *radio_current_location;
+	GtkWidget  *radio_last_location;
+	GtkWidget  *radio_use_startup;
+	GtkWidget  *startup_dir_filechooserbutton;
+	GtkWidget  *btn_set_to_current;
+	GtkWidget  *radio_layout1;
+	GtkWidget  *radio_layout2;
+	GtkWidget  *radio_layout3;
+	GtkWidget  *radio_layout4;
+	GtkWidget  *toolbar_style_optionmenu;
 
-	GtkWidget *view_as_slides_radiobutton;
-	GtkWidget *view_as_list_radiobutton;
-	/*GtkWidget *toggle_show_hidden;*/
-	GtkWidget *toggle_show_filenames;
-	GtkWidget *toggle_show_comments;
-	GtkWidget *toggle_show_thumbs;
-	GtkWidget *toggle_file_type;
-	GtkWidget *opt_thumbs_size;
-	GtkWidget *toggle_confirm_del;
-	GtkWidget *toggle_ask_to_save;
-	GtkWidget *opt_click_policy;
+	GtkWidget  *view_as_slides_radiobutton;
+	GtkWidget  *view_as_list_radiobutton;
+	GtkWidget  *toggle_show_filenames;
+	GtkWidget  *toggle_show_comments;
+	GtkWidget  *toggle_show_thumbs;
+	GtkWidget  *toggle_file_type;
+	GtkWidget  *opt_thumbs_size;
+	GtkWidget  *toggle_confirm_del;
+	GtkWidget  *toggle_ask_to_save;
+	GtkWidget  *opt_click_policy;
 
-	GtkWidget *opt_zoom_quality_high;
-	GtkWidget *opt_zoom_quality_low;
-	GtkWidget *opt_zoom_change;
-	GtkWidget *opt_transparency;
+	GtkWidget  *opt_zoom_quality_high;
+	GtkWidget  *opt_zoom_quality_low;
+	GtkWidget  *opt_zoom_change;
+	GtkWidget  *opt_transparency;
 
-	GtkWidget *radio_ss_direction_forward;
-	GtkWidget *radio_ss_direction_reverse;
-	GtkWidget *radio_ss_direction_random;
-	GtkWidget *spin_ss_delay;
-	GtkWidget *toggle_ss_wrap_around;
-	GtkWidget *toggle_ss_fullscreen;
+	GtkWidget  *radio_ss_direction_forward;
+	GtkWidget  *radio_ss_direction_reverse;
+	GtkWidget  *radio_ss_direction_random;
+	GtkWidget  *spin_ss_delay;
+	GtkWidget  *toggle_ss_wrap_around;
 } DialogData;
 
 
@@ -121,19 +117,15 @@ apply_cb (GtkWidget  *widget,
 	eel_gconf_set_boolean (PREF_USE_STARTUP_LOCATION, gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (data->radio_use_startup)));
 
 	if (eel_gconf_get_boolean (PREF_USE_STARTUP_LOCATION, FALSE)) {
-		char *temp;
-		char *text;
+		char *esc_path;
 		char *location;
 
-		text = _gtk_entry_get_filename_text (GTK_ENTRY (data->startup_dir_entry));
-		temp = remove_ending_separator (text);
-		location = g_strconcat ("file://", temp, NULL);
+		esc_path = gtk_file_chooser_get_uri (GTK_FILE_CHOOSER (data->startup_dir_filechooserbutton));
+		location = gnome_vfs_unescape_string (esc_path, "");
+		g_free (esc_path);
 
 		eel_gconf_set_path (PREF_STARTUP_LOCATION, location);
 		preferences_set_startup_location (location);
-
-		g_free (temp);
-		g_free (text);
 		g_free (location);
 	}
 
@@ -141,8 +133,6 @@ apply_cb (GtkWidget  *widget,
 
 	eel_gconf_set_boolean (PREF_SLIDESHOW_WRAP_AROUND, gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (data->toggle_ss_wrap_around)));
 
-	eel_gconf_set_boolean (PREF_SLIDESHOW_FULLSCREEN, gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (data->toggle_ss_fullscreen)));
-
 	eel_gconf_set_integer (PREF_SLIDESHOW_DELAY, gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (data->spin_ss_delay)));
 
 	/**/
@@ -206,7 +196,7 @@ static void
 use_startup_toggled_cb (GtkWidget *widget, 
 			DialogData *data)
 {
-	gtk_widget_set_sensitive (data->file_entry,
+	gtk_widget_set_sensitive (data->startup_dir_filechooserbutton,
 				  GTK_TOGGLE_BUTTON (widget)->active);
 	gtk_widget_set_sensitive (data->btn_set_to_current,
 				  GTK_TOGGLE_BUTTON (widget)->active);
@@ -218,11 +208,11 @@ static void
 set_to_current_cb (GtkWidget  *widget, 
 		   DialogData *data)
 {
-	if (data->window->dir_list->path == NULL)
-		return;
+	char *esc_uri;
 
-	_gtk_entry_set_filename_text (GTK_ENTRY (data->startup_dir_entry), 
-				      data->window->dir_list->path);
+	esc_uri = gnome_vfs_escape_host_and_path_string (gth_browser_get_current_directory (data->browser));
+	gtk_file_chooser_set_uri (GTK_FILE_CHOOSER (data->startup_dir_filechooserbutton), esc_uri);
+	g_free (esc_uri);
 }
 
 
@@ -394,7 +384,7 @@ transp_type_changed_cb (GtkOptionMenu *option_menu,
 
 /* create the main dialog. */
 void
-dlg_preferences (GThumbWindow *window)
+dlg_preferences (GthBrowser *browser)
 {
 	DialogData       *data;
 	GtkWidget        *btn_close;
@@ -402,11 +392,9 @@ dlg_preferences (GThumbWindow *window)
 	int               layout_type;
 	char             *startup_location;
 	GthDirectionType  direction;
-	GValue            value = {0, };
-	GtkWidget        *fileentry;
 
 	data = g_new (DialogData, 1);
-	data->window = window;
+	data->browser = browser;
 	data->gui = glade_xml_new (GTHUMB_GLADEDIR "/" GLADE_PREF_FILE, NULL, NULL);
         if (!data->gui) {
                 g_warning ("Could not find " GLADE_PREF_FILE "\n");
@@ -425,8 +413,7 @@ dlg_preferences (GThumbWindow *window)
         data->radio_current_location = glade_xml_get_widget (data->gui, "radio_current_location");
         data->radio_last_location = glade_xml_get_widget (data->gui, "radio_last_location");
         data->radio_use_startup = glade_xml_get_widget (data->gui, "radio_use_startup");
-        data->startup_dir_entry = glade_xml_get_widget (data->gui, "startup_dir_entry");
-        data->file_entry = glade_xml_get_widget (data->gui, "file_entry");
+        data->startup_dir_filechooserbutton = glade_xml_get_widget (data->gui, "startup_dir_filechooserbutton");
 	data->btn_set_to_current = glade_xml_get_widget (data->gui, "btn_set_to_current");
         data->toggle_confirm_del = glade_xml_get_widget (data->gui, "toggle_confirm_del");
         data->toggle_ask_to_save = glade_xml_get_widget (data->gui, "toggle_ask_to_save");
@@ -458,20 +445,12 @@ dlg_preferences (GThumbWindow *window)
         data->radio_ss_direction_random = glade_xml_get_widget (data->gui, "radio_ss_direction_random");
         data->spin_ss_delay = glade_xml_get_widget (data->gui, "spin_ss_delay");
         data->toggle_ss_wrap_around = glade_xml_get_widget (data->gui, "toggle_ss_wrap_around");
-        data->toggle_ss_fullscreen = glade_xml_get_widget (data->gui, "toggle_ss_fullscreen");
 
 	btn_close  = glade_xml_get_widget (data->gui, "p_close_button");
 	btn_help   = glade_xml_get_widget (data->gui, "p_help_button");
 
 	/* Set widgets data. */
 
-	/* Make use of new filechooser */
-
-	g_value_init (&value, G_TYPE_BOOLEAN);
-	g_value_set_boolean (&value, TRUE);
-	fileentry = glade_xml_get_widget (data->gui, "file_entry");
-	g_object_set_property (G_OBJECT (fileentry), "use_filechooser", &value);
-
 	/* * general */
 
 	if (eel_gconf_get_boolean (PREF_USE_STARTUP_LOCATION, FALSE))
@@ -482,15 +461,22 @@ dlg_preferences (GThumbWindow *window)
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (data->radio_current_location), TRUE);
 	
 	if (! eel_gconf_get_boolean (PREF_USE_STARTUP_LOCATION, FALSE)) {
-		gtk_widget_set_sensitive (data->file_entry, FALSE);
+		gtk_widget_set_sensitive (data->startup_dir_filechooserbutton, FALSE);
 		gtk_widget_set_sensitive (data->btn_set_to_current, FALSE);
 	}
 
 	startup_location = eel_gconf_get_path (PREF_STARTUP_LOCATION, NULL);
-
+	
 	if ((startup_location != NULL)
-	    && pref_util_location_is_file (startup_location)) 
-		_gtk_entry_set_filename_text (GTK_ENTRY (data->startup_dir_entry), pref_util_get_file_location (startup_location));
+	    && pref_util_location_is_file (startup_location)) {
+		const char *uri;
+		char       *esc_uri;
+
+		uri = pref_util_get_file_location (startup_location);
+		esc_uri = gnome_vfs_escape_host_and_path_string (uri);
+		gtk_file_chooser_set_uri (GTK_FILE_CHOOSER (data->startup_dir_filechooserbutton), esc_uri);
+		g_free (esc_uri);
+	}
 
 	g_free (startup_location);
 
@@ -542,7 +528,7 @@ dlg_preferences (GThumbWindow *window)
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (data->opt_zoom_quality_low), TRUE);
 
 	gtk_option_menu_set_history (GTK_OPTION_MENU (data->opt_zoom_change), pref_get_zoom_change ());
-	gtk_option_menu_set_history (GTK_OPTION_MENU (data->opt_transparency), image_viewer_get_transp_type (IMAGE_VIEWER (window->viewer)));
+	gtk_option_menu_set_history (GTK_OPTION_MENU (data->opt_transparency), image_viewer_get_transp_type (gth_window_get_image_viewer (GTH_WINDOW (browser))));
 
 	/* * slide show */
 
@@ -557,7 +543,6 @@ dlg_preferences (GThumbWindow *window)
 	gtk_spin_button_set_value (GTK_SPIN_BUTTON (data->spin_ss_delay),
 				   (gfloat) eel_gconf_get_integer (PREF_SLIDESHOW_DELAY, 4));
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (data->toggle_ss_wrap_around), eel_gconf_get_boolean (PREF_SLIDESHOW_WRAP_AROUND, FALSE));
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (data->toggle_ss_fullscreen), eel_gconf_get_boolean (PREF_SLIDESHOW_FULLSCREEN, TRUE));
 
 	/* Set the signals handlers. */
 
@@ -670,7 +655,8 @@ dlg_preferences (GThumbWindow *window)
 
 	/* run dialog. */
 
-	gtk_window_set_transient_for (GTK_WINDOW (data->dialog), GTK_WINDOW (window->app));
+	gtk_window_set_transient_for (GTK_WINDOW (data->dialog), 
+				      GTK_WINDOW (browser));
 	gtk_window_set_modal (GTK_WINDOW (data->dialog), FALSE);
 	gtk_widget_show_all (data->dialog);
 }
