@@ -25,16 +25,15 @@
 #include <stdlib.h>
 #include <stdio.h>
 #include <string.h>
+
+#include <glib/gi18n.h>
 #include <gtk/gtk.h>
 #include <libgnome/gnome-url.h>
-#include <libgnomeui/gnome-file-entry.h>
-#include <libgnomeui/gnome-dialog-util.h>
-#include <libgnomeui/gnome-color-picker.h>
-#include <libgnomeui/gnome-font-picker.h>
 #include <libgnomevfs/gnome-vfs-directory.h>
 #include <libgnomevfs/gnome-vfs-ops.h>
 #include <libgnomevfs/gnome-vfs-utils.h>
 #include <glade/glade.h>
+
 #include "catalog-web-exporter.h"
 #include "dlg-file-utils.h"
 #include "file-utils.h"
@@ -43,25 +42,26 @@
 #include "main.h"
 #include "pixbuf-utils.h"
 #include "gconf-utils.h"
-#include "gthumb-window.h"
+#include "gth-browser.h"
 #include "glib-utils.h"
 
-static int           sort_method_to_idx[] = { -1, 0, 1, 2, 3 };
+static int           sort_method_to_idx[] = { -1, 0, 1, 2, 3, 4 };
 static GthSortMethod idx_to_sort_method[] = { GTH_SORT_METHOD_BY_NAME, 
 					      GTH_SORT_METHOD_BY_PATH, 
 					      GTH_SORT_METHOD_BY_SIZE, 
-					      GTH_SORT_METHOD_BY_TIME };
+					      GTH_SORT_METHOD_BY_TIME,
+					      GTH_SORT_METHOD_MANUAL};
 static int           idx_to_resize_width[] = { 320, 640, 800, 1024, 1280 };
 static int           idx_to_resize_height[] = { 200, 480, 600, 768, 960 };
 
 
 #define str_void(x) (((x) == NULL) || (*(x) == 0))
 #define GLADE_EXPORTER_FILE "gthumb_web_exporter.glade"
-#define MAX_PREVIEW_SIZE 150
+#define MAX_PREVIEW_SIZE 220
 
 
 typedef struct {
-	GThumbWindow       *window;
+	GthBrowser         *browser;
 
 	GladeXML           *gui;
 	GtkWidget          *dialog;
@@ -73,8 +73,7 @@ typedef struct {
 
 	GtkWidget          *btn_ok;
 
-	GtkWidget          *wa_destination_entry;
-	GtkWidget          *wa_destination_button;
+	GtkWidget          *wa_destination_filechooserbutton;
 	GtkWidget          *wa_index_file_entry;
 	GtkWidget          *wa_copy_images_checkbutton;
 	GtkWidget          *wa_resize_images_checkbutton;
@@ -84,7 +83,7 @@ typedef struct {
 
 	GtkWidget          *wa_rows_spinbutton;
 	GtkWidget          *wa_cols_spinbutton;
-	GtkWidget          *wa_sort_images_optionmenu;
+	GtkWidget          *wa_sort_images_combobox;
 	GtkWidget          *wa_reverse_order_checkbutton;
 
 	GtkWidget          *wa_header_entry;
@@ -124,7 +123,7 @@ export (GtkWidget  *widget,
 
 	/* Save options. */
 
-	esc_path = _gtk_entry_get_filename_text (GTK_ENTRY (data->wa_destination_entry));
+	esc_path = gtk_file_chooser_get_uri (GTK_FILE_CHOOSER (data->wa_destination_filechooserbutton));
 	path = gnome_vfs_unescape_string (esc_path, "");
 	location = remove_ending_separator (path);
 	g_free (path);
@@ -147,7 +146,7 @@ export (GtkWidget  *widget,
 
 	eel_gconf_set_integer (PREF_WEB_ALBUM_COLUMNS, gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (data->wa_cols_spinbutton)));
 
-	pref_set_web_album_sort_order (idx_to_sort_method [gtk_option_menu_get_history (GTK_OPTION_MENU (data->wa_sort_images_optionmenu))]);
+	pref_set_web_album_sort_order (idx_to_sort_method [gtk_combo_box_get_active (GTK_COMBO_BOX (data->wa_sort_images_combobox))]);
 
 	eel_gconf_set_boolean (PREF_WEB_ALBUM_REVERSE, gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (data->wa_reverse_order_checkbutton)));
 
@@ -162,7 +161,7 @@ export (GtkWidget  *widget,
 
 	/**/
 
-	if (! dlg_check_folder (data->window, location)) {
+	if (! dlg_check_folder (GTH_WINDOW (data->browser), location)) {
 		g_free (location);
 		return;
 	}
@@ -195,7 +194,7 @@ export (GtkWidget  *widget,
 	/* Export. */
 
 	gtk_window_set_transient_for (GTK_WINDOW (data->progress_dialog),
-				      GTK_WINDOW (data->window->app));
+				      GTK_WINDOW (data->browser));
 	gtk_window_set_modal (GTK_WINDOW (data->progress_dialog), TRUE);
 	gtk_widget_show_all (data->progress_dialog);
 
@@ -275,72 +274,33 @@ resize_image_toggled_cb (GtkToggleButton *button,
 }
 
 
-static void
-open_response_cb (GtkDialog  *file_sel,
-		  int         button_number,
-		  gpointer    userdata)
-{
-	DialogData  *data = (DialogData   * )userdata;
-
-	if (button_number == GTK_RESPONSE_ACCEPT) {
-		_gtk_entry_set_filename_text (GTK_ENTRY (data->wa_destination_entry),
-					      gtk_file_chooser_get_uri (GTK_FILE_CHOOSER (file_sel)));
-	}
-	gtk_widget_destroy (GTK_WIDGET (file_sel));
-}
-
-
-static void
-wa_destination_button_clicked_cb (GtkWidget  *button,
-				  gpointer    data)
-{
-	GtkWidget *file_sel;
-	
-	file_sel = gtk_file_chooser_dialog_new (_("Choose destination folder"),
-						NULL,
-						GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER, 
-						GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL, 
-						GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT,
-						NULL);
-	gtk_window_set_modal (GTK_WINDOW (file_sel), TRUE);
-
-	gtk_file_chooser_set_local_only (GTK_FILE_CHOOSER (file_sel), FALSE);
-	g_signal_connect (G_OBJECT (file_sel),
-			  "response",
-			  G_CALLBACK (open_response_cb),
-			  data);
-	
-	g_signal_connect_swapped (GTK_DIALOG (file_sel),
-				  "close",
-				  G_CALLBACK (gtk_widget_destroy),
-				  GTK_WIDGET (file_sel));
-	
-	gtk_widget_show_all (GTK_WIDGET (file_sel));
-}
-
-
 /* create the main dialog. */
 void
-dlg_web_exporter (GThumbWindow *window)
+dlg_web_exporter (GthBrowser *browser)
 {
 	DialogData   *data;
 	GtkWidget    *btn_cancel;
 	GtkWidget    *btn_help;
 	GList        *list;
 	char         *svalue;
+	char         *esc_uri;
+	gboolean      reorderable;
+	int           idx;
 
-	data = g_new (DialogData, 1);
+	data = g_new0 (DialogData, 1);
 
-	data->window = window;
-
-	list = gth_file_view_get_file_list_selection (window->file_list->view);
+	data->browser = browser;
+	
+	list = gth_window_get_file_list_selection (GTH_WINDOW (browser));
 	if (list == NULL) {
 		g_warning ("No file selected.");
 		g_free (data);
 		return;
 	}
 
-	data->exporter = catalog_web_exporter_new (window, list);
+	reorderable = gth_file_view_get_reorderable (gth_browser_get_file_view (browser));
+
+	data->exporter = catalog_web_exporter_new (GTH_WINDOW (browser), list);
 	g_list_foreach (list, (GFunc) g_free, NULL);
 	g_list_free (list);
 
@@ -355,8 +315,7 @@ dlg_web_exporter (GThumbWindow *window)
 	/* Get the widgets. */
 	
 	data->dialog = glade_xml_get_widget (data->gui, "web_album_dialog");
-	data->wa_destination_entry = glade_xml_get_widget (data->gui, "wa_destination_entry");
-	data->wa_destination_button = glade_xml_get_widget (data->gui, "wa_destination_button");
+	data->wa_destination_filechooserbutton = glade_xml_get_widget (data->gui, "wa_destination_filechooserbutton");
 	data->wa_index_file_entry = glade_xml_get_widget (data->gui, "wa_index_file_entry");
 	data->wa_copy_images_checkbutton = glade_xml_get_widget (data->gui, "wa_copy_images_checkbutton");
 
@@ -367,7 +326,7 @@ dlg_web_exporter (GThumbWindow *window)
 
 	data->wa_rows_spinbutton = glade_xml_get_widget (data->gui, "wa_rows_spinbutton");
 	data->wa_cols_spinbutton = glade_xml_get_widget (data->gui, "wa_cols_spinbutton");
-	data->wa_sort_images_optionmenu = glade_xml_get_widget (data->gui, "wa_sort_images_optionmenu");
+	data->wa_sort_images_combobox = glade_xml_get_widget (data->gui, "wa_sort_images_combobox");
 	data->wa_reverse_order_checkbutton = glade_xml_get_widget (data->gui, "wa_reverse_order_checkbutton");
 
 	data->wa_header_entry = glade_xml_get_widget (data->gui, "wa_header_entry");
@@ -406,7 +365,24 @@ dlg_web_exporter (GThumbWindow *window)
 
 	gtk_spin_button_set_value (GTK_SPIN_BUTTON (data->wa_cols_spinbutton), eel_gconf_get_integer (PREF_WEB_ALBUM_COLUMNS, 4));
 
-	gtk_option_menu_set_history (GTK_OPTION_MENU (data->wa_sort_images_optionmenu), sort_method_to_idx [pref_get_web_album_sort_order ()]);
+	/**/
+
+	gtk_combo_box_append_text (GTK_COMBO_BOX (data->wa_sort_images_combobox),
+				   _("by path"));
+	gtk_combo_box_append_text (GTK_COMBO_BOX (data->wa_sort_images_combobox),
+				   _("by size"));
+	gtk_combo_box_append_text (GTK_COMBO_BOX (data->wa_sort_images_combobox),
+				   _("by modified time"));
+	if (reorderable)
+		gtk_combo_box_append_text (GTK_COMBO_BOX (data->wa_sort_images_combobox),
+					   _("manual order"));
+
+	idx = sort_method_to_idx [pref_get_web_album_sort_order ()];
+	if (!reorderable && (sort_method_to_idx[GTH_SORT_METHOD_MANUAL] == idx))
+		idx = sort_method_to_idx[GTH_SORT_METHOD_BY_NAME];
+	gtk_combo_box_set_active (GTK_COMBO_BOX (data->wa_sort_images_combobox), idx);
+
+	/**/
 
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (data->wa_reverse_order_checkbutton), eel_gconf_get_boolean (PREF_WEB_ALBUM_REVERSE, FALSE));
 
@@ -428,8 +404,12 @@ dlg_web_exporter (GThumbWindow *window)
 	/**/
 
 	svalue = eel_gconf_get_path (PREF_WEB_ALBUM_DESTINATION, NULL);
-	_gtk_entry_set_filename_text (GTK_ENTRY (data->wa_destination_entry),
-				      (((svalue == NULL) || (*svalue == 0)) ? g_get_home_dir() : svalue));
+	if (svalue == NULL)
+		esc_uri = gnome_vfs_escape_host_and_path_string (g_get_home_dir ());
+	else
+		esc_uri = gnome_vfs_escape_host_and_path_string (svalue);
+	gtk_file_chooser_set_uri (GTK_FILE_CHOOSER (data->wa_destination_filechooserbutton), esc_uri);
+	g_free (esc_uri);
 	g_free (svalue);
 
 	/* Signals. */
@@ -438,10 +418,6 @@ dlg_web_exporter (GThumbWindow *window)
 			  "destroy",
 			  G_CALLBACK (destroy_cb),
 			  data);
-	g_signal_connect (G_OBJECT (data->wa_destination_button), 
-			  "clicked",
-			  G_CALLBACK (wa_destination_button_clicked_cb),
-			  data);
 	g_signal_connect_swapped (G_OBJECT (btn_cancel), 
 				  "clicked",
 				  G_CALLBACK (gtk_widget_destroy),
@@ -493,9 +469,7 @@ dlg_web_exporter (GThumbWindow *window)
 
 	/* Run dialog. */
 
-	gtk_widget_grab_focus (data->wa_destination_entry);
-
-	gtk_window_set_transient_for (GTK_WINDOW (data->dialog), GTK_WINDOW (window->app));
+	gtk_window_set_transient_for (GTK_WINDOW (data->dialog), GTK_WINDOW (browser));
 	gtk_window_set_modal (GTK_WINDOW (data->dialog), FALSE);
 	gtk_widget_show_all (data->dialog);
 }
@@ -505,7 +479,7 @@ dlg_web_exporter (GThumbWindow *window)
 
 typedef struct {
 	DialogData         *data;
-	GThumbWindow       *window;
+	GthBrowser         *browser;
 
 	GladeXML           *gui;
 	GtkWidget          *dialog;
@@ -596,7 +570,7 @@ add_theme_dir (ThemeDialogData *tdata,
 			    || (strcmp (info->name, "..") == 0))
 				continue;
 
-			utf8_name = g_filename_to_utf8 (info->name, -1, NULL, NULL, NULL);
+			utf8_name = g_filename_display_name (info->name);
 			
 			gtk_list_store_append (tdata->list_store, &iter);
 			gtk_list_store_set (tdata->list_store, &iter,
@@ -776,16 +750,12 @@ theme_dialog__go_to_folder_clicked (GtkWidget       *widget,
 				    ThemeDialogData *tdata)
 {
 	char         *path;
-        GnomeVFSURI  *uri;
 	GError       *err;
 
 	path = g_strdup_printf ("file://%s/.gnome2/gthumb/albumthemes", 
 			       g_get_home_dir ());
 
-	uri = gnome_vfs_uri_new (path);
-	if (! gnome_vfs_uri_exists (uri)) 
-		gnome_vfs_make_directory_for_uri (uri, 0775);
-        gnome_vfs_uri_unref (uri);
+	ensure_dir_exists (path, 0775);
 
 	if (! gnome_url_show (path, &err))
 		_gtk_error_dialog_from_gerror_run (GTK_WINDOW (tdata->dialog),
@@ -876,7 +846,7 @@ show_album_theme_cb (GtkWidget  *widget,
 	tdata = g_new (ThemeDialogData, 1);
 
 	tdata->data = data;
-	tdata->window = data->window;
+	tdata->browser = data->browser;
 
 	tdata->gui = glade_xml_new (GTHUMB_GLADEDIR "/" GLADE_EXPORTER_FILE, NULL, NULL);
         if (!tdata->gui) {
@@ -976,7 +946,7 @@ show_album_theme_cb (GtkWidget  *widget,
 
 typedef struct {
 	DialogData         *data;
-	GThumbWindow       *window;
+	GthBrowser         *browser;
 
 	GladeXML           *gui;
 	GtkWidget          *dialog;
@@ -1072,7 +1042,7 @@ show_caption_dialog_cb (GtkWidget       *widget,
 	cdata = g_new (CaptionDialogData, 1);
 
 	cdata->data = tdata->data;
-	cdata->window = tdata->window;
+	cdata->browser = tdata->browser;
 	cdata->thumbnail_caption = thumbnail_caption;
 
 	cdata->gui = glade_xml_new (GTHUMB_GLADEDIR "/" GLADE_EXPORTER_FILE, NULL, NULL);
